@@ -5,44 +5,47 @@
 import sys
 import os
 import platform
-import pkgutil
+#import pkgutil
 from ctypes import *
 
-try: # decide how files are unpacked depending on if we have the pkg_resources module
+try:  # decide how files are unpacked depending on if we have the pkg_resources module
     from pkg_resources import resource_filename
+
     def _unpackfile(filename):
         return resource_filename(__name__, filename)
 except ImportError:
-    from tdl import __path__
+    from untdl import __path__
+
     def _unpackfile(filename):
         return os.path.abspath(os.path.join(__path__[0], filename))
 
-def _unpackFramework(framework, path):
+
+def _unpack_framework(framework, path):
     """get framework.tar file, remove ".tar" and add path"""
     return os.path.abspath(os.path.join(_unpackfile(framework)[:-4], path))
 
-def _loadDLL(dll):
+
+def _load_dll(dll):
     """shorter version of file unpacking and linking"""
     return cdll.LoadLibrary(_unpackfile(dll))
     
     
 def _get_library_crossplatform():
     bits, linkage = platform.architecture()
-    libpath = None
     if 'win32' in sys.platform:
-        libSDL = _loadDLL('lib/win32/SDL.dll')
-        libZ = _loadDLL('lib/win32/zlib1.dll')
-        libTCOD = _loadDLL('lib/win32/libtcod-VS.dll')
+        libSDL = _load_dll('lib/win32/SDL.dll')
+        libZ = _load_dll('lib/win32/zlib1.dll')
+        libTCOD = _load_dll('lib/win32/libtcod-VS.dll')
     elif 'linux' in sys.platform:
         libSDL = None
         #libSDL = cdll.LoadLibrary('SDL.so')
         if bits == '32bit':
-            libTCOD = _loadDLL('lib/linux32/libtcod.so')
+            libTCOD = _load_dll('lib/linux32/libtcod.so')
         elif bits == '64bit':
-            libTCOD = _loadDLL('lib/linux64/libtcod.so')
+            libTCOD = _load_dll('lib/linux64/libtcod.so')
     elif 'darwin' in sys.platform:
-        libSDL = _loadDLL('lib/darwin/SDL.dylib')
-        libTCOD = _loadDLL('lib/darwin/libtcod.dylib')
+        libSDL = _load_dll('lib/darwin/SDL.dylib')
+        libTCOD = _load_dll('lib/darwin/libtcod.dylib')
         
     else:
         raise ImportError('Operating system "%s" has no supported dynamic link libarary. (%s, %s)' % (sys.platform, bits, linkage))
@@ -313,7 +316,7 @@ BKGND_ALPH = 12
 # just for reference:
 #define TCOD_BKGND_ALPHA(alpha) ((TCOD_bkgnd_flag_t)(TCOD_BKGND_ALPH|(((uint8)(alpha*255))<<8)))
 #define TCOD_BKGND_ADDALPHA(alpha) ((TCOD_bkgnd_flag_t)(TCOD_BKGND_ADDA|(((uint8)(alpha*255))<<8)))
-# these are already in tdl
+# these are already in untdl
 
 TCOD_bkgnd_flag_t = c_int
 TCOD_renderer_t = c_int
@@ -625,7 +628,7 @@ RNG_CMWC = 2 # Multiply-with-carry
 
 TCOD_random_t = c_void_p
 
-#TCODLIB_API TCOD_random_t TCOD_random_new_from_seed(TCOD_random_algo_t algo, uint32 seed);
+#TCODLIB_API TCOD_random_t TCOD_random_new_from_seed(TCOD_random_algo_t algorithm, uint32 seed);
 _lib.TCOD_random_new_from_seed.restype = TCOD_random_t
 _lib.TCOD_random_new_from_seed.argtypes = (c_int, c_uint32)
 #TCODLIB_API void TCOD_random_delete(TCOD_random_t mersenne);
